docs.rs failed to build tauri-runtime-blitz-0.1.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Tauri runtime backed by Blitz and Boa.
The first implementation target is Tauri 2.11.x. Its runtime traits are not semver-stable, so versions stay exact and upgrades are deliberate.